import boto3
import awswrangler as wr
import base64
import pandas as pd
import warnings
import re
import enum

class Sheet(enum.Enum):
        Patients="Patients"
        Baseline="Baseline"
        FollowUpDetails="Follow-Up Details"
        SurgicalResection="Surgical Resection"
        Objects="Objects"
        Diagnosis="Diagnosis"
        Correlations="Correlations"

class QuentryAnalyticsClient:
    def __init__(self, auth_token: str) -> None:
        self._bucket_name = "poc-data-for-google-colab"
        try:
            self._boto3_session = boto3.Session(
                aws_access_key_id=auth_token.split(";")[0],
                aws_secret_access_key=auth_token.split(";")[1]
            )
            sts = self._boto3_session.client('sts')
            caller_identity = sts.get_caller_identity()
            print(f"logged in as: {caller_identity['Arn']}")
        except:
            raise Exception("There was an error with your auth token.")

        
    def getDataFrame(self, filename: str, sheet: Sheet) -> pd.DataFrame:
        file_url = f"s3://{self._bucket_name}/{filename}"
        warnings.filterwarnings('ignore', category=UserWarning, module=re.escape('openpyxl.styles.stylesheet'))
        return wr.s3.read_excel(file_url, sheet_name=sheet.value, boto3_session=self._boto3_session)